from datetime import datetime

from cpl_core.database import TableABC

from bot_data.model.team_member_type_enum import TeamMemberTypeEnum


class ServerTeamRoleIdsConfig(TableABC):
    def __init__(
        self,
        role_id: int,
        team_member_type: TeamMemberTypeEnum,
        server_id: int,
        created_at: datetime = None,
        modified_at: datetime = None,
        id=0,
    ):
        self._id = id
        self._role_id = role_id
        self._team_member_type = team_member_type
        self._server_id = server_id

        TableABC.__init__(self)
        self._created_at = created_at if created_at is not None else self._created_at
        self._modified_at = modified_at if modified_at is not None else self._modified_at

    @property
    def id(self) -> int:
        return self._id

    @property
    def role_id(self) -> int:
        return self._role_id

    @property
    def team_member_type(self) -> TeamMemberTypeEnum:
        return self._team_member_type

    @staticmethod
    def get_select_all_string() -> str:
        return str(
            f"""
                SELECT * FROM `CFG_ServerTeamRoleIds`;
            """
        )

    @staticmethod
    def get_select_by_id_string(id: int) -> str:
        return str(
            f"""
                SELECT * FROM `CFG_ServerTeamRoleIds`
                WHERE `Id` = {id};
            """
        )

    @staticmethod
    def get_select_by_server_id_string(server_id: int) -> str:
        return str(
            f"""
                SELECT * FROM `CFG_ServerTeamRoleIds`
                WHERE `ServerId` = {server_id};
            """
        )

    @property
    def insert_string(self) -> str:
        return str(
            f"""
                INSERT INTO `CFG_ServerTeamRoleIds` (
                    `RoleId`,
                    `TeamMemberType`,
                    `ServerId`
                ) VALUES (
                    {self._role_id},
                    '{self._team_member_type.value}',
                    {self._server_id}
                );
            """
        )

    @property
    def udpate_string(self) -> str:
        return str(
            f"""
                UPDATE `CFG_ServerTeamRoleIds`
                SET `RoleId` = {self._role_id},
                `TeamMemberType` = '{self._team_member_type.value}',
                `ServerId` = {self._server_id}
                WHERE `Id` = {self._id};
            """
        )

    @property
    def delete_string(self) -> str:
        return str(
            f"""
                DELETE FROM `CFG_ServerTeamRoleIds`
                WHERE `RoleId` = {self._role_id};
            """
        )
